E CVS: apps/entrance xcomputerman

2006-05-13 Thread Enlightenment CVS
Enlightenment CVS committal

Author  : xcomputerman
Project : e17
Module  : apps/entrance

Dir : e17/apps/entrance/src/client


Modified Files:
entrance_x_session.c 


Log Message:
Found the little critter. Session objects defaulting to layer 0 because their 
layers were not set.

===
RCS file: /cvs/e/e17/apps/entrance/src/client/entrance_x_session.c,v
retrieving revision 1.9
retrieving revision 1.10
diff -u -3 -r1.9 -r1.10
--- entrance_x_session.c23 Mar 2005 03:12:40 -  1.9
+++ entrance_x_session.c13 May 2006 06:40:10 -  1.10
@@ -100,6 +100,7 @@
if (edje_object_file_set(edje, themefile, Session)  0)
{
   evas_object_move(edje, -, -);
+  evas_object_layer_set(edje, 2);
   edje_object_size_min_get(edje, w, h);
   if ((w  0)  (h  0))
  evas_object_resize(result, w, h);




---
Using Tomcat but need to do more? Need to support web services, security?
Get stuff done quickly with pre-integrated technology to make your job easier
Download IBM WebSphere Application Server v.1.0.1 based on Apache Geronimo
http://sel.as-us.falkag.net/sel?cmd=lnkkid=120709bid=263057dat=121642
___
enlightenment-cvs mailing list
enlightenment-cvs@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/enlightenment-cvs


E CVS: apps/entrance xcomputerman

2006-05-13 Thread Enlightenment CVS
Enlightenment CVS committal

Author  : xcomputerman
Project : e17
Module  : apps/entrance

Dir : e17/apps/entrance/src/client


Modified Files:
entrance_x_session.c 


Log Message:
Put sessions on same layer as main Edje.


===
RCS file: /cvs/e/e17/apps/entrance/src/client/entrance_x_session.c,v
retrieving revision 1.10
retrieving revision 1.11
diff -u -3 -r1.10 -r1.11
--- entrance_x_session.c13 May 2006 06:40:10 -  1.10
+++ entrance_x_session.c13 May 2006 08:46:57 -  1.11
@@ -100,7 +100,7 @@
if (edje_object_file_set(edje, themefile, Session)  0)
{
   evas_object_move(edje, -, -);
-  evas_object_layer_set(edje, 2);
+  evas_object_layer_set(edje, 1);
   edje_object_size_min_get(edje, w, h);
   if ((w  0)  (h  0))
  evas_object_resize(result, w, h);




---
Using Tomcat but need to do more? Need to support web services, security?
Get stuff done quickly with pre-integrated technology to make your job easier
Download IBM WebSphere Application Server v.1.0.1 based on Apache Geronimo
http://sel.as-us.falkag.net/sel?cmd=lnkkid=120709bid=263057dat=121642
___
enlightenment-cvs mailing list
enlightenment-cvs@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/enlightenment-cvs


E CVS: apps/entrance xcomputerman

2006-05-13 Thread Enlightenment CVS
Enlightenment CVS committal

Author  : xcomputerman
Project : e17
Module  : apps/entrance

Dir : e17/apps/entrance


Modified Files:
README README.edje 


Log Message:
README updates.


===
RCS file: /cvs/e/e17/apps/entrance/README,v
retrieving revision 1.12
retrieving revision 1.13
diff -u -3 -r1.12 -r1.13
--- README  16 Aug 2005 04:04:04 -  1.12
+++ README  13 May 2006 08:47:34 -  1.13
@@ -5,10 +5,10 @@
 1. To put into a trance.
 2. To fill with delight, wonder, or enchantment.
 
-Entrance is the next generation of Elogin, a login/display manager for
-Linux XFree86 systems. It is designed to be extremely customizable and
-aesthetically attractive -- a refreshing relief from the traditional
-dull and boring interfaces of XDM and its descendants.
+Entrance is a login/display manager for UNIX X11 displays. It is 
+designed to be extremely customizable and aesthetically attractive
+-- a refreshing relief from the traditional dull and boring interfaces 
+of XDM and its descendants.
 
 Compiling  Installing
 --
@@ -16,9 +16,8 @@
 To compile, you need the following libraries (if you're using a
 package-based system, be sure to install the devel packages):
 
-- Evas (= 1.0.0pre12). Evas 0.6 will NOT work.
-- Edb (= 1.0.3)
-- Ecore (= 1.0.0pre4). You must have Ecore_Evas support.
+- Evas
+- Ecore
 - Edje
 - Esmart
 - PAM (optional)
@@ -64,6 +63,12 @@
 config settings appropriately so that crypt/shadow authentication is used
 instead. If you wish to manually set the authentication method, edit the
 /entrance/auth entry in the config db (1 for PAM, 2 for crypt/shadow).
+
+You may specify a custom background Edje file for Entrance by modifying
+the /entrance/background key in your Entrance config. Entrance can load
+background collections from Entrance themes or E17 background files. If
+no background is specified, Entrance will use the default background
+specified in your theme.
 
 Take a look at README.edje for a guide to the theme format and a detailed
 explanation of how sessions and users work.
===
RCS file: /cvs/e/e17/apps/entrance/README.edje,v
retrieving revision 1.7
retrieving revision 1.8
diff -u -3 -r1.7 -r1.8
--- README.edje 10 Dec 2004 22:26:56 -  1.7
+++ README.edje 13 May 2006 08:47:34 -  1.8
@@ -7,6 +7,8 @@
 1. A Parts Collection Must be Present, Titled Main
 2. Entrance makes use of the parts of Main.  If the required column is
 set to No it is an optional feature for the themer.
+3. A Background collection must also be present, titled Background, and
+   must be defined before the Main collection.
 
 A Complete listing of Edje parts Entrance is aware of
 -




---
Using Tomcat but need to do more? Need to support web services, security?
Get stuff done quickly with pre-integrated technology to make your job easier
Download IBM WebSphere Application Server v.1.0.1 based on Apache Geronimo
http://sel.as-us.falkag.net/sel?cmd=lnkkid=120709bid=263057dat=121642
___
enlightenment-cvs mailing list
enlightenment-cvs@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/enlightenment-cvs


E CVS: e kwo

2006-05-13 Thread Enlightenment CVS
Enlightenment CVS committal

Author  : kwo
Project : e16
Module  : e

Dir : e16/e/src


Modified Files:
ipc.c 


Log Message:
Fix warning.

===
RCS file: /cvs/e/e16/e/src/ipc.c,v
retrieving revision 1.267
retrieving revision 1.268
diff -u -3 -r1.267 -r1.268
--- ipc.c   29 Apr 2006 19:39:21 -  1.267
+++ ipc.c   13 May 2006 09:47:13 -  1.268
@@ -140,6 +140,7 @@
int l;
const char *p;
 
+   param[0] = '\0';
p = params;
if (p)
  {




---
Using Tomcat but need to do more? Need to support web services, security?
Get stuff done quickly with pre-integrated technology to make your job easier
Download IBM WebSphere Application Server v.1.0.1 based on Apache Geronimo
http://sel.as-us.falkag.net/sel?cmd=lnkkid=120709bid=263057dat=121642
___
enlightenment-cvs mailing list
enlightenment-cvs@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/enlightenment-cvs


E CVS: e kwo

2006-05-13 Thread Enlightenment CVS
Enlightenment CVS committal

Author  : kwo
Project : e16
Module  : e

Dir : e16/e/src


Modified Files:
e16-ecore_list.c 


Log Message:
Remove inline's. I doubt they make much sense here.

===
RCS file: /cvs/e/e16/e/src/e16-ecore_list.c,v
retrieving revision 1.4
retrieving revision 1.5
diff -u -3 -r1.4 -r1.5
--- e16-ecore_list.c16 Apr 2006 23:00:45 -  1.4
+++ e16-ecore_list.c13 May 2006 10:03:08 -  1.5
@@ -255,7 +255,7 @@
  * @return  @c FALSE if an error occurs, @c TRUE if appended successfully
  * @ingroup Ecore_Data_List_Add_Item_Group
  */
-EAPI inline int
+EAPI int
 ecore_list_append(Ecore_List * list, void *data)
 {
int ret;
@@ -304,7 +304,7 @@
  * @return @c FALSE if an error occurs, @c TRUE if prepended successfully.
  * @ingroup Ecore_Data_List_Add_Item_Group
  */
-EAPI inline int
+EAPI int
 ecore_list_prepend(Ecore_List * list, void *data)
 {
int ret;
@@ -346,7 +346,7 @@
  * @return  @c FALSE if there is an error, @c TRUE on success
  * @ingroup Ecore_Data_List_Add_Item_Group
  */
-EAPI inline int
+EAPI int
 ecore_list_insert(Ecore_List * list, void *data)
 {
int ret;
@@ -411,7 +411,7 @@
  * @return  A pointer to the removed data on success, @c NULL on failure.
  * @ingroup Ecore_Data_List_Remove_Item_Group
  */
-EAPI inline void   *
+EAPI void  *
 ecore_list_remove(Ecore_List * list)
 {
void   *ret;
@@ -489,7 +489,7 @@
  *  failure.
  * @ingroup Ecore_Data_List_Remove_Item_Group
  */
-EAPI inline void   *
+EAPI void  *
 ecore_list_remove_first(Ecore_List * list)
 {
void   *ret;
@@ -544,7 +544,7 @@
  * @return  A pointer to the removed data on success, @c NULL on failure.
  * @ingroup Ecore_Data_List_Remove_Item_Group
  */
-EAPI inline void   *
+EAPI void  *
 ecore_list_remove_last(Ecore_List * list)
 {
void   *ret;
@@ -616,7 +616,7 @@
  * @return  A pointer to new current item on success, @c NULL on failure.
  * @ingroup Ecore_Data_List_Traverse_Group
  */
-EAPI inline void   *
+EAPI void  *
 ecore_list_goto_index(Ecore_List * list, int indx)
 {
void   *ret;
@@ -664,7 +664,7 @@
  * @return  A pointer to @p data on success, @c NULL on failure.
  * @ingroup Ecore_Data_List_Traverse_Group
  */
-EAPI inline void   *
+EAPI void  *
 ecore_list_goto(Ecore_List * list, void *data)
 {
void   *ret;
@@ -718,7 +718,7 @@
  * @return  A pointer to the first item on success, @c NULL on failure
  * @ingroup Ecore_Data_List_Traverse_Group
  */
-EAPI inline void   *
+EAPI void  *
 ecore_list_goto_first(Ecore_List * list)
 {
void   *ret;
@@ -749,7 +749,7 @@
  * @return  A pointer to the last item on success, @c NULL on failure.
  * @ingroup Ecore_Data_List_Traverse_Group
  */
-EAPI inline void   *
+EAPI void  *
 ecore_list_goto_last(Ecore_List * list)
 {
void   *ret;
@@ -779,7 +779,7 @@
  * @param  list The list.
  * @return Returns the data at current position, can be @c NULL.
  */
-EAPI inline void   *
+EAPI void  *
 ecore_list_current(Ecore_List * list)
 {
void   *ret;
@@ -809,7 +809,7 @@
  * @param   list The list to retrieve data from.
  * @return  The current item in the list on success, @c NULL on failure.
  */
-EAPI inline void   *
+EAPI void  *
 ecore_list_next(Ecore_List * list)
 {
void   *data;




---
Using Tomcat but need to do more? Need to support web services, security?
Get stuff done quickly with pre-integrated technology to make your job easier
Download IBM WebSphere Application Server v.1.0.1 based on Apache Geronimo
http://sel.as-us.falkag.net/sel?cmd=lnkkid=120709bid=263057dat=121642
___
enlightenment-cvs mailing list
enlightenment-cvs@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/enlightenment-cvs


E CVS: proto moom

2006-05-13 Thread Enlightenment CVS
Enlightenment CVS committal

Author  : moom
Project : e17
Module  : proto

Dir : e17/proto/etk/doc/img


Added Files:
label.png menu.png menu_bar.png 


Log Message:
* The widgets can now change the focus order of their children.
* Implementation of a correct focus order in Etk_Box






---
Using Tomcat but need to do more? Need to support web services, security?
Get stuff done quickly with pre-integrated technology to make your job easier
Download IBM WebSphere Application Server v.1.0.1 based on Apache Geronimo
http://sel.as-us.falkag.net/sel?cmd=lnkkid=120709bid=263057dat=121642
___
enlightenment-cvs mailing list
enlightenment-cvs@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/enlightenment-cvs


E CVS: proto moom

2006-05-13 Thread Enlightenment CVS
Enlightenment CVS committal

Author  : moom
Project : e17
Module  : proto

Dir : e17/proto/etk/src/lib


Modified Files:
etk_bin.h etk_box.c etk_toplevel_widget.c etk_widget.c 
etk_widget.h 


Log Message:
* The widgets can now change the focus order of their children.
* Implementation of a correct focus order in Etk_Box


===
RCS file: /cvs/e/e17/proto/etk/src/lib/etk_bin.h,v
retrieving revision 1.5
retrieving revision 1.6
diff -u -3 -r1.5 -r1.6
--- etk_bin.h   12 May 2006 19:13:39 -  1.5
+++ etk_bin.h   13 May 2006 12:04:00 -  1.6
@@ -5,6 +5,10 @@
 #include etk_container.h
 #include etk_types.h
 
+/* TODO: Etk_Bin
+ - The swallow code should be included in Etk_Widget.c
+ */
+
 /**
  * @defgroup Etk_Bin Etk_Bin
  * @brief The Etk_Bin widget is a container that can contain only one child
===
RCS file: /cvs/e/e17/proto/etk/src/lib/etk_box.c,v
retrieving revision 1.10
retrieving revision 1.11
diff -u -3 -r1.10 -r1.11
--- etk_box.c   12 May 2006 19:13:39 -  1.10
+++ etk_box.c   13 May 2006 12:04:00 -  1.11
@@ -274,6 +274,7 @@
ETK_CONTAINER(box)-child_add = _etk_box_child_add;
ETK_CONTAINER(box)-child_remove = _etk_box_child_remove;
ETK_CONTAINER(box)-children_get = _etk_box_children_get;
+   ETK_WIDGET(box)-use_focus_order = ETK_TRUE;
 }
 
 /* Destroys the box */
@@ -356,6 +357,7 @@
  etk_widget_parent_set_full(widget, NULL, ETK_FALSE);
  free(cell);
  box-cells = evas_list_remove_list(box-cells, l);
+ ETK_WIDGET(box)-focus_order = 
evas_list_remove(ETK_WIDGET(box)-focus_order, widget);
  etk_widget_size_recalc_queue(ETK_WIDGET(box));
  return;
   }
@@ -784,11 +786,13 @@
  *
  **/
 
-/* Adds the child to the box : expand and fill describe its fill 
policy, padding is the size of the space
- * on the sides of the child and if pack_end == ETK_TRUE, the child will be 
packed at the end of the box */
+/* Adds the child to the box : expand and fill describe its fill 
policy, padding is the amount of space
+ * on the sides of the child and. If pack_end == ETK_TRUE, the child will be 
packed at the end of the box */
 static void _etk_box_pack_full(Etk_Box *box, Etk_Widget *child, Etk_Bool 
expand, Etk_Bool fill, int padding, Etk_Bool pack_end)
 {
-   Etk_Box_Cell *cell;
+   Etk_Box_Cell *cell, *last_cell;
+   Evas_List *l;
+   Etk_Widget *w;

if (!box || !child)
   return;
@@ -799,6 +803,26 @@
cell-padding = padding;
cell-pack_end = pack_end;
cell-child = child;
+   
+   /* Adds the child in the focus_order list, at the right place */
+   last_cell = evas_list_data(evas_list_last(box-cells));
+   if (!last_cell)
+  ETK_WIDGET(box)-focus_order = 
evas_list_append(ETK_WIDGET(box)-focus_order, child);
+   else
+   {
+  for (l = ETK_WIDGET(box)-focus_order; l; l = l-next)
+  {
+ w = ETK_WIDGET(l-data);
+ if (w == last_cell-child)
+ {
+if (last_cell-pack_end)
+   ETK_WIDGET(box)-focus_order = 
evas_list_prepend_relative(ETK_WIDGET(box)-focus_order, child, l);
+else
+   ETK_WIDGET(box)-focus_order = 
evas_list_append_relative(ETK_WIDGET(box)-focus_order, child, l);
+break;
+ }
+  }
+   }

box-cells = evas_list_append(box-cells, cell);
etk_widget_parent_set(child, ETK_WIDGET(box));
===
RCS file: /cvs/e/e17/proto/etk/src/lib/etk_toplevel_widget.c,v
retrieving revision 1.14
retrieving revision 1.15
diff -u -3 -r1.14 -r1.15
--- etk_toplevel_widget.c   7 Apr 2006 15:36:11 -   1.14
+++ etk_toplevel_widget.c   13 May 2006 12:04:00 -  1.15
@@ -112,39 +112,39 @@
 }
 
 /**
- * @brief Gets the next widget to focus. Mainly for widget implementations
+ * @brief Gets the previous widget to focus.  Mainly for widget implementations
  * @param toplevel_widget a toplevel widget
- * @return Returns the next widget to focus
+ * @return Returns the previous widget to focus
  */
-Etk_Widget *etk_toplevel_widget_focused_widget_next_get(Etk_Toplevel_Widget 
*toplevel_widget)
+Etk_Widget *etk_toplevel_widget_focused_widget_prev_get(Etk_Toplevel_Widget 
*toplevel_widget)
 {
Etk_Widget *focused_parent;
 
if (!toplevel_widget)
   return NULL;
 
-   if (toplevel_widget-focused_widget  (focused_parent = 
ETK_WIDGET(toplevel_widget-focused_widget-parent)))
-  return _etk_toplevel_widget_next_to_focus_get(focused_parent, 
toplevel_widget-focused_widget);
+   if (toplevel_widget-focused_widget  (focused_parent = 
toplevel_widget-focused_widget-parent))
+  return _etk_toplevel_widget_prev_to_focus_get(focused_parent, 
toplevel_widget-focused_widget);
else
-  return 
_etk_toplevel_widget_next_to_focus_get(ETK_WIDGET(toplevel_widget), 

E CVS: proto moom

2006-05-13 Thread Enlightenment CVS
Enlightenment CVS committal

Author  : moom
Project : e17
Module  : proto

Dir : e17/proto/etk/data/icons/default/icons/16x16/actions


Modified Files:
dialog-ok.png dialog-yes.png 


Log Message:
* Full rereading and documentation of the following files:
   - etk_alignment.c/h
   - etk_bin.c/h
   - etk_box.c/h
   - etk_button.c/h
   - etk_cache.c/h
   - etk_canvas.c/h
   - etk_combobox.c/h
   - etk_container.c/h
   - etk_dialog.c/h
   - etk_frame.c/h
   - etk_iconbox.c/h
   - etk_image.c/h
   - etk_label.c/h
   - etk_main.c/h
   - etk_marshallers.c/h

The signals and the properties of these files are now fully 
documented. The html doc also looks like the other e-related sites.

Several small bugs have been also fixed, though I don't remember which 
ones exactly. Most important ones are:
   - Child padding is now taken in account by the boxes
   - Implementation of etk_canvas_object_remove()


===
RCS file: 
/cvs/e/e17/proto/etk/data/icons/default/icons/16x16/actions/dialog-ok.png,v
retrieving revision 1.1
retrieving revision 1.2
diff -u -3 -r1.1 -r1.2
Binary files /tmp/cvsf0yaUB and /tmp/cvssylwJb differ
===
RCS file: 
/cvs/e/e17/proto/etk/data/icons/default/icons/16x16/actions/dialog-yes.png,v
retrieving revision 1.1
retrieving revision 1.2
diff -u -3 -r1.1 -r1.2
Binary files /tmp/cvsEmUnSC and /tmp/cvsGmTeJc differ




---
Using Tomcat but need to do more? Need to support web services, security?
Get stuff done quickly with pre-integrated technology to make your job easier
Download IBM WebSphere Application Server v.1.0.1 based on Apache Geronimo
http://sel.as-us.falkag.net/sel?cmd=lnkkid=120709bid=263057dat=121642
___
enlightenment-cvs mailing list
enlightenment-cvs@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/enlightenment-cvs


E CVS: proto moom

2006-05-13 Thread Enlightenment CVS
Enlightenment CVS committal

Author  : moom
Project : e17
Module  : proto

Dir : e17/proto/etk


Modified Files:
Doxyfile TODO gendoc 


Log Message:
* Full rereading and documentation of the following files:
   - etk_alignment.c/h
   - etk_bin.c/h
   - etk_box.c/h
   - etk_button.c/h
   - etk_cache.c/h
   - etk_canvas.c/h
   - etk_combobox.c/h
   - etk_container.c/h
   - etk_dialog.c/h
   - etk_frame.c/h
   - etk_iconbox.c/h
   - etk_image.c/h
   - etk_label.c/h
   - etk_main.c/h
   - etk_marshallers.c/h

The signals and the properties of these files are now fully 
documented. The html doc also looks like the other e-related sites.

Several small bugs have been also fixed, though I don't remember which 
ones exactly. Most important ones are:
   - Child padding is now taken in account by the boxes
   - Implementation of etk_canvas_object_remove()


===
RCS file: /cvs/e/e17/proto/etk/Doxyfile,v
retrieving revision 1.1
retrieving revision 1.2
diff -u -3 -r1.1 -r1.2
--- Doxyfile1 Oct 2005 16:29:44 -   1.1
+++ Doxyfile12 May 2006 19:13:38 -  1.2
@@ -18,7 +18,7 @@
 GENERATE_CHI   = NO
 BINARY_TOC = NO
 TOC_EXPAND = NO
-DISABLE_INDEX  = NO
+DISABLE_INDEX  = YES
 EXTRACT_ALL= NO
 EXTRACT_PRIVATE= NO
 EXTRACT_STATIC = NO
@@ -28,7 +28,7 @@
 HIDE_FRIEND_COMPOUNDS  = YES
 BRIEF_MEMBER_DESC  = YES
 REPEAT_BRIEF   = YES
-ALWAYS_DETAILED_SEC= NO
+ALWAYS_DETAILED_SEC= YES
 INLINE_INHERITED_MEMB  = NO
 FULL_PATH_NAMES= NO
 STRIP_FROM_PATH= 
@@ -41,22 +41,34 @@
 SHOW_INCLUDE_FILES = NO
 JAVADOC_AUTOBRIEF  = NO
 MULTILINE_CPP_IS_BRIEF = NO
-DETAILS_AT_TOP = NO
+DETAILS_AT_TOP = YES
 INHERIT_DOCS   = YES
 INLINE_INFO= YES
-SORT_MEMBER_DOCS   = YES
+SORT_MEMBER_DOCS   = NO
 DISTRIBUTE_GROUP_DOC   = NO
-TAB_SIZE   = 2
+TAB_SIZE   = 3
 GENERATE_TODOLIST  = YES
 GENERATE_TESTLIST  = YES
 GENERATE_BUGLIST   = YES
 GENERATE_DEPRECATEDLIST= YES
-ALIASES= 
+ALIASES= widget=b[Widget]/b
+ALIASES   += [EMAIL PROTECTED] For more informations, see the 
documention page of the corresponding module (link above or in the 
i\Widgets\/i page)
+ALIASES   += prop_name=- @b
+ALIASES   += prop_type=   - ttType:/tt
+ALIASES   += prop_rw=   - ttAccess:/tt Read/Write
+ALIASES   += prop_ro=   - ttAccess:/tt Read Only
+ALIASES   += prop_wo=   - ttAccess:/tt Write Only
+ALIASES   += prop_na=   - ttAccess:/tt No Access
+ALIASES   += prop_val=   - ttDefault Value:/tt
+ALIASES   += signal_name=- @b
+ALIASES   += signal_cb=   - ttCallback:/tt
+ALIASES   += signal_arg= - @c
+ALIASES   += signal_data= - @c data: the user data set when 
the callback has been connected to the signal
 ENABLED_SECTIONS   = 
 MAX_INITIALIZER_LINES  = 30
 OPTIMIZE_OUTPUT_FOR_C  = YES
 OPTIMIZE_OUTPUT_JAVA   = NO
-SHOW_USED_FILES= NO
+SHOW_USED_FILES= YES
 QUIET  = NO
 WARNINGS   = YES
 WARN_IF_UNDOCUMENTED   = YES
@@ -78,10 +90,10 @@
 REFERENCES_RELATION= YES
 ALPHABETICAL_INDEX = YES
 COLS_IN_ALPHA_INDEX= 2
-IGNORE_PREFIX  = 
+IGNORE_PREFIX  = Etk_
 GENERATE_TREEVIEW  = NO
 TREEVIEW_WIDTH = 250
-GENERATE_LATEX = YES
+GENERATE_LATEX = NO
 LATEX_OUTPUT   = latex
 LATEX_CMD_NAME = latex
 MAKEINDEX_CMD_NAME = makeindex
@@ -98,11 +110,11 @@
 RTF_HYPERLINKS = NO
 RTF_STYLESHEET_FILE= 
 RTF_EXTENSIONS_FILE= 
-GENERATE_MAN   = YES
+GENERATE_MAN   = NO
 MAN_OUTPUT = man
 MAN_EXTENSION  = .3
 MAN_LINKS  = YES
-GENERATE_XML   = YES
+GENERATE_XML   = NO
 XML_SCHEMA = 
 XML_DTD= 
 GENERATE_AUTOGEN_DEF   = NO
===
RCS file: /cvs/e/e17/proto/etk/TODO,v
retrieving revision 1.10
retrieving revision 1.11
diff -u -3 -r1.10 -r1.11
--- TODO7 Apr 2006 15:36:08 -   1.10
+++ TODO12 May 2006 19:13:38 -  1.11
@@ -13,14 +13,12 @@
 * The labels sometimes does not returns its ideal size requisition (happens 
when there is a br)
 Maybe a bug of the evas textblock
 * Fix and optimize the colorpicker
-* Sometimes, the mouse cursor is not reset when you stop resizing a row in the 
tree (and also segv)
 
 
 [Things that need to be improved (in order of pripority)]
 
 * Improve the entry: add selection supports, better keyboard navigation [In 
progress: MoOm]
-* Add a cache system to cache images used by the tree and the future iconbox 
in order to make
-the scrolling smoother 

E CVS: proto moom

2006-05-13 Thread Enlightenment CVS
Enlightenment CVS committal

Author  : moom
Project : e17
Module  : proto

Dir : e17/proto/etk/data/icons/default/icons/22x22/actions


Modified Files:
dialog-ok.png dialog-yes.png 


Log Message:
* Full rereading and documentation of the following files:
   - etk_alignment.c/h
   - etk_bin.c/h
   - etk_box.c/h
   - etk_button.c/h
   - etk_cache.c/h
   - etk_canvas.c/h
   - etk_combobox.c/h
   - etk_container.c/h
   - etk_dialog.c/h
   - etk_frame.c/h
   - etk_iconbox.c/h
   - etk_image.c/h
   - etk_label.c/h
   - etk_main.c/h
   - etk_marshallers.c/h

The signals and the properties of these files are now fully 
documented. The html doc also looks like the other e-related sites.

Several small bugs have been also fixed, though I don't remember which 
ones exactly. Most important ones are:
   - Child padding is now taken in account by the boxes
   - Implementation of etk_canvas_object_remove()


===
RCS file: 
/cvs/e/e17/proto/etk/data/icons/default/icons/22x22/actions/dialog-ok.png,v
retrieving revision 1.1
retrieving revision 1.2
diff -u -3 -r1.1 -r1.2
Binary files /tmp/cvsvRZZoJ and /tmp/cvscezOpj differ
===
RCS file: 
/cvs/e/e17/proto/etk/data/icons/default/icons/22x22/actions/dialog-yes.png,v
retrieving revision 1.1
retrieving revision 1.2
diff -u -3 -r1.1 -r1.2
Binary files /tmp/cvsYMNqcK and /tmp/cvsoRGJek differ




---
Using Tomcat but need to do more? Need to support web services, security?
Get stuff done quickly with pre-integrated technology to make your job easier
Download IBM WebSphere Application Server v.1.0.1 based on Apache Geronimo
http://sel.as-us.falkag.net/sel?cmd=lnkkid=120709bid=263057dat=121642
___
enlightenment-cvs mailing list
enlightenment-cvs@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/enlightenment-cvs


E CVS: proto moom

2006-05-13 Thread Enlightenment CVS
Enlightenment CVS committal

Author  : moom
Project : e17
Module  : proto

Dir : e17/proto/etk/src/bin


Modified Files:
etk_test.c 


Log Message:
* Full rereading and documentation of the following files:
   - etk_alignment.c/h
   - etk_bin.c/h
   - etk_box.c/h
   - etk_button.c/h
   - etk_cache.c/h
   - etk_canvas.c/h
   - etk_combobox.c/h
   - etk_container.c/h
   - etk_dialog.c/h
   - etk_frame.c/h
   - etk_iconbox.c/h
   - etk_image.c/h
   - etk_label.c/h
   - etk_main.c/h
   - etk_marshallers.c/h

The signals and the properties of these files are now fully 
documented. The html doc also looks like the other e-related sites.

Several small bugs have been also fixed, though I don't remember which 
ones exactly. Most important ones are:
   - Child padding is now taken in account by the boxes
   - Implementation of etk_canvas_object_remove()


===
RCS file: /cvs/e/e17/proto/etk/src/bin/etk_test.c,v
retrieving revision 1.19
retrieving revision 1.20
diff -u -3 -r1.19 -r1.20
--- etk_test.c  7 Apr 2006 15:36:10 -   1.19
+++ etk_test.c  12 May 2006 19:13:39 -  1.20
@@ -125,7 +125,7 @@
if (!etk_init())
{
   fprintf(stderr, Could not init etk. Exiting...\n);
-  return 0;
+  return 1;
};
 
etk_tooltips_enable();
@@ -133,7 +133,7 @@
etk_main();
etk_shutdown();
 
-   return 1;
+   return 0;
 }
 
 /* Creates the main window */




---
Using Tomcat but need to do more? Need to support web services, security?
Get stuff done quickly with pre-integrated technology to make your job easier
Download IBM WebSphere Application Server v.1.0.1 based on Apache Geronimo
http://sel.as-us.falkag.net/sel?cmd=lnkkid=120709bid=263057dat=121642
___
enlightenment-cvs mailing list
enlightenment-cvs@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/enlightenment-cvs


E CVS: apps/euphoria tilman

2006-05-13 Thread Enlightenment CVS
Enlightenment CVS committal

Author  : tilman
Project : e17
Module  : apps/euphoria

Dir : e17/apps/euphoria/lib


Modified Files:
slider.rb 


Log Message:
some fixes for xmms2-devel

===
RCS file: /cvs/e/e17/apps/euphoria/lib/slider.rb,v
retrieving revision 1.2
retrieving revision 1.3
diff -u -3 -r1.2 -r1.3
--- slider.rb   7 Jul 2005 16:33:56 -   1.2
+++ slider.rb   13 May 2006 14:59:17 -  1.3
@@ -1,4 +1,4 @@
-# $Id: slider.rb,v 1.2 2005/07/07 16:33:56 tsauerbeck Exp $
+# $Id: slider.rb,v 1.3 2006/05/13 14:59:17 tilman Exp $
 
 class Slider
def initialize(edje, xmms, part, config)
@@ -27,12 +27,26 @@
 class VolumeSlider  Slider
attr_reader :part, :config
 
-   def initialize(edje, xmms, part, config)
-   super
+   def initialize(edje, xmms, part)
+   @edje = edje
+   @xmms = xmms
+   @part = part
+   @val = nil
+
+   self.value = @xmms.playback_volume_get.wait.value
+
+   @edje.on_signal(drag, @part) do
+   v = on_drag(@edje.part(@part).get_drag_value)
+
+   unless v.nil?
+   @xmms.playback_volume_set(left, v).wait
+   @xmms.playback_volume_set(right, v).wait
+   end
+   end
end
 
def value=(v)
-   v = (1.0 - v.split(/)[0].to_f / 100.0).abs
+   v = (1.0 - (v[:left].to_f / 100.0)).abs
 
if [EMAIL PROTECTED] || @val != v
@val = v
@@ -46,7 +60,7 @@
 
if @val != v
@val = v
-   ret = %i/%i % [].fill(v * 100, 0..1)
+   ret = (v * 100).to_i
end
 
ret
@@ -55,10 +69,6 @@
 
 class EqSlider  Slider
attr_reader :part, :config
-
-   def initialize(edje, xmms, part, config)
-   super
-   end
 
def value=(v)
v = (1.0 - v.to_f).abs




---
Using Tomcat but need to do more? Need to support web services, security?
Get stuff done quickly with pre-integrated technology to make your job easier
Download IBM WebSphere Application Server v.1.0.1 based on Apache Geronimo
http://sel.as-us.falkag.net/sel?cmd=lnkkid=120709bid=263057dat=121642
___
enlightenment-cvs mailing list
enlightenment-cvs@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/enlightenment-cvs


E CVS: apps/e raster

2006-05-13 Thread Enlightenment CVS
Enlightenment CVS committal

Author  : raster
Project : e17
Module  : apps/e

Dir : e17/apps/e


Modified Files:
TODO 


Log Message:


handle spaces in eap filenames when editing, and proeprly escape things, add
gneric escaper, and reduce file path of icon files nicely.

===
RCS file: /cvs/e/e17/apps/e/TODO,v
retrieving revision 1.325
retrieving revision 1.326
diff -u -3 -r1.325 -r1.326
--- TODO13 May 2006 14:23:42 -  1.325
+++ TODO13 May 2006 15:20:15 -  1.326
@@ -8,7 +8,6 @@
   BUGS / FIXES
 ---
 
-* BUG: eap editor doesn't handle spaces in file paths for the .eap
 * BUG: ghost windows happen if windows close when on another desktop or if
   windows are very short-lived
 * BUG: k3b has minimization issues when burning cds (it tries to unminimize




---
Using Tomcat but need to do more? Need to support web services, security?
Get stuff done quickly with pre-integrated technology to make your job easier
Download IBM WebSphere Application Server v.1.0.1 based on Apache Geronimo
http://sel.as-us.falkag.net/sel?cmd=lnkkid=120709bid=263057dat=121642
___
enlightenment-cvs mailing list
enlightenment-cvs@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/enlightenment-cvs


E CVS: apps/e raster

2006-05-13 Thread Enlightenment CVS
Enlightenment CVS committal

Author  : raster
Project : e17
Module  : apps/e

Dir : e17/apps/e/src/bin


Modified Files:
e_apps.c e_utils.c e_utils.h 


Log Message:


handle spaces in eap filenames when editing, and proeprly escape things, add
gneric escaper, and reduce file path of icon files nicely.

===
RCS file: /cvs/e/e17/apps/e/src/bin/e_apps.c,v
retrieving revision 1.132
retrieving revision 1.133
diff -u -3 -r1.132 -r1.133
--- e_apps.c13 May 2006 14:57:20 -  1.132
+++ e_apps.c13 May 2006 15:20:15 -  1.133
@@ -1419,7 +1419,7 @@
 static int
 _e_app_new_save(E_App *a)
 {
-   static char tmpn[1024];
+   static char tmpn[4096];
int fd = 0, ret = 0;
char cmd[2048];  
char ipart[512];
@@ -1446,20 +1446,13 @@
  }

i = 0;
-   
if (a-image)
  {
start = strchr(a-image, '/');
-   end = strrchr(a-image ,'/');
+   end = strrchr(a-image, '/');
 
-   if (start == end)
- {
-imgdir = strdup(/);;
- }
-   else if ((!start) || (!end))
- {
-imgdir = strdup();
- }
+   if (start == end) imgdir = strdup(/);
+   else if ((!start) || (!end)) imgdir = strdup();
else
  {
 imgdir = malloc((end - start + 1));
@@ -1473,24 +1466,27 @@
 
if (imgdir)
  {
-   snprintf(ipart, sizeof(ipart), -id %s, imgdir);
+   snprintf(ipart, sizeof(ipart), -id %s,
+e_util_filename_escape(imgdir));
free(imgdir);
  }
-   else ipart[0] = '\0';
+   else ipart[0] = 0;

if (a-image)
  {
-   if (a-width = 0)
- a-width = EAP_MIN_WIDTH;
-   if (a-height = 0)
- a-height = EAP_MIN_HEIGHT;
-   fprintf(out, EAP_EDC_TMPL, a-image, a-width, a-height, a-image);
+   if (a-width = 0) a-width = EAP_MIN_WIDTH;
+   if (a-height = 0) a-height = EAP_MIN_HEIGHT;
+   fprintf(out, EAP_EDC_TMPL, 
+   e_util_filename_escape(ecore_file_get_file(a-image)), 
+   a-width, a-height, 
+   e_util_filename_escape(ecore_file_get_file(a-image)));
  }
else
  fprintf(out, EAP_EDC_TMPL_EMPTY);
fclose(out);

-   snprintf(cmd, sizeof(cmd), edje_cc -v %s %s %s, ipart, tmpn, a-path);
+   snprintf(cmd, sizeof(cmd), edje_cc -v %s %s %s, ipart, tmpn, 
+   e_util_filename_escape(a-path));
ret = system(cmd);

if (ret  0)
@@ -1500,7 +1496,7 @@
return 0;
  }

-   unlink(tmpn);
+   ecore_file_unlink(tmpn);
return 1;   
 }
 
===
RCS file: /cvs/e/e17/apps/e/src/bin/e_utils.c,v
retrieving revision 1.41
retrieving revision 1.42
diff -u -3 -r1.41 -r1.42
--- e_utils.c   30 Apr 2006 04:31:42 -  1.41
+++ e_utils.c   13 May 2006 15:20:15 -  1.42
@@ -527,6 +527,38 @@
e_dialog_show(dia);
 }
 
+EAPI const char *
+e_util_filename_escape(const char *filename)
+{
+   char *p, *q;
+   static char buf[4096];
+   
+   p = filename;
+   q = buf;
+   while (*p)
+ {
+   if ((q - buf)  4090) return NULL;
+   if (
+   (*p == ' ') || (*p == '\t') || (*p == '\n') ||
+   (*p == '\\') || (*p == '\'') || (*p == '\') ||
+   (*p == ';') || (*p == '!') || (*p == '#') ||
+   (*p == '$') || (*p == '%') || (*p == '') ||
+   (*p == '*') || (*p == '(') || (*p == ')') ||
+   (*p == '[') || (*p == ']') || (*p == '{') ||
+   (*p == '}') || (*p == '|') || (*p == '') ||
+   (*p == '') || (*p == '?')
+   )
+ {
+*q = '\\';
+q++;
+ }
+   *q = *p;
+   q++;
+   p++;
+ }
+   return buf;
+}
+
 /* local subsystem functions */
 static void
 _e_util_container_fake_mouse_up_cb(void *data)
===
RCS file: /cvs/e/e17/apps/e/src/bin/e_utils.h,v
retrieving revision 1.22
retrieving revision 1.23
diff -u -3 -r1.22 -r1.23
--- e_utils.h   2 Mar 2006 12:03:48 -   1.22
+++ e_utils.h   13 May 2006 15:20:15 -  1.23
@@ -39,6 +39,7 @@
 EAPI E_Border*e_util_desk_border_below(E_Border *bd);
 EAPI int  e_util_edje_collection_exists(const char *file, const char 
*coll);
 EAPI void e_util_dialog_internal(const char *title, const char *txt);
-
+EAPI const char  *e_util_filename_escape(const char *filename);
+
 #endif
 #endif




---
Using Tomcat but need to do more? Need to support web services, security?
Get stuff done quickly with pre-integrated technology to make your job easier
Download IBM WebSphere Application Server v.1.0.1 based on Apache Geronimo
http://sel.as-us.falkag.net/sel?cmd=lnkkid=120709bid=263057dat=121642
___
enlightenment-cvs mailing list
enlightenment-cvs@lists.sourceforge.net

E CVS: language sndev

2006-05-13 Thread Enlightenment CVS
Enlightenment CVS committal

Author  : sndev
Project : e_modules
Module  : language

Dir : e_modules/language


Modified Files:
  Tag: 1.41
e_mod_config.c e_mod_keybind.c e_mod_lang.c e_mod_lang.h 
e_mod_main.c e_mod_main.h 


Log Message:

More work on the module. 

* The config dialog is almost finished.
* The user interface should work fine.
* The config is stored an load properly.





---
Using Tomcat but need to do more? Need to support web services, security?
Get stuff done quickly with pre-integrated technology to make your job easier
Download IBM WebSphere Application Server v.1.0.1 based on Apache Geronimo
http://sel.as-us.falkag.net/sel?cmd=lnkkid=120709bid=263057dat=121642
___
enlightenment-cvs mailing list
enlightenment-cvs@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/enlightenment-cvs


E CVS: language sndev

2006-05-13 Thread Enlightenment CVS
Enlightenment CVS committal

Author  : sndev
Project : e_modules
Module  : language

Dir : e_modules/language


Added Files:
  Tag: 1.10
TODO 


Log Message:

todo





---
Using Tomcat but need to do more? Need to support web services, security?
Get stuff done quickly with pre-integrated technology to make your job easier
Download IBM WebSphere Application Server v.1.0.1 based on Apache Geronimo
http://sel.as-us.falkag.net/sel?cmd=lnkkid=120709bid=263057dat=121642
___
enlightenment-cvs mailing list
enlightenment-cvs@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/enlightenment-cvs


E CVS: proto titan

2006-05-13 Thread Enlightenment CVS
Enlightenment CVS committal

Author  : titan
Project : e17
Module  : proto

Dir : e17/proto/ephoto/src


Modified Files:
ephoto.c ephoto_misc.c ephoto_browsing.c ephoto_presentation.c 
ephoto.h 


Log Message:

Add an option to zoom every image to fit the window, even if the image is 
smaller than the window. Minor code cleanups.

===
RCS file: /cvs/e/e17/proto/ephoto/src/ephoto.c,v
retrieving revision 1.43
retrieving revision 1.44
diff -u -3 -r1.43 -r1.44
--- ephoto.c18 Apr 2006 03:09:25 -  1.43
+++ ephoto.c13 May 2006 21:06:16 -  1.44
@@ -271,14 +271,14 @@
m-win = ewl_window_new();
ewl_window_title_set(EWL_WINDOW(m-win), ephoto);
ewl_window_name_set(EWL_WINDOW(m-win), ephoto);
-   ewl_object_size_request(EWL_OBJECT(m-win), 640, 500);
+   ewl_object_size_request(EWL_OBJECT(m-win), 640, 480);
ewl_callback_append(m-win, EWL_CALLBACK_DELETE_WINDOW, 
destroy_cb, NULL);
ewl_widget_show(m-win);
mainwin = 1;
 
m-avbox = ewl_vbox_new();
ewl_container_child_append(EWL_CONTAINER(m-win), m-avbox);
-   ewl_object_fill_policy_set(EWL_OBJECT(m-avbox), 
EWL_FLAG_FILL_ALL);
+   ewl_object_fill_policy_set(EWL_OBJECT(m-avbox), 
EWL_FLAG_FILL_ALL | EWL_FLAG_FILL_SHRINK);
ewl_widget_show(m-avbox);
 
m-menubar = ewl_hmenubar_new();
@@ -366,21 +366,22 @@
m-hbox = ewl_hpaned_new();
ewl_object_alignment_set(EWL_OBJECT(m-hbox), 
EWL_FLAG_ALIGN_CENTER);
ewl_container_child_append(EWL_CONTAINER(m-avbox), m-hbox);
+   ewl_object_fill_policy_set(EWL_OBJECT(m-hbox), 
EWL_FLAG_FILL_ALL | EWL_FLAG_FILL_SHRINK);
ewl_widget_show(m-hbox);
 
m-vbox = ewl_vbox_new();
ewl_object_alignment_set(EWL_OBJECT(m-vbox), 
EWL_FLAG_ALIGN_CENTER);
ewl_box_spacing_set(EWL_BOX(m-vbox), 10);
-   ewl_object_preferred_inner_size_set(EWL_OBJECT(m-vbox), 200, 
30);
+   ewl_object_preferred_inner_size_set(EWL_OBJECT(m-vbox), 200, 
45);
ewl_container_child_append(EWL_CONTAINER(m-hbox), m-vbox);
+   ewl_object_fill_policy_set(EWL_OBJECT(m-vbox), 
EWL_FLAG_FILL_VFILL | EWL_FLAG_FILL_VSHRINK | EWL_FLAG_FILL_HSHRINK);
ewl_widget_show(m-vbox);
 
m-images = ewl_border_new();
ewl_border_text_set(EWL_BORDER(m-images), Add Content);
ewl_border_label_alignment_set(EWL_BORDER(m-images), 
EWL_FLAG_ALIGN_CENTER);
ewl_container_child_append(EWL_CONTAINER(m-vbox), m-images);
-   ewl_object_maximum_size_set(EWL_OBJECT(m-images), 200, 99);
-   ewl_object_fill_policy_set(EWL_OBJECT(m-images), 
EWL_FLAG_FILL_ALL);   
+   ewl_object_fill_policy_set(EWL_OBJECT(m-images), 
EWL_FLAG_FILL_VFILL | EWL_FLAG_FILL_VSHRINK); 
ewl_widget_show(m-images);
 
m-directory = ewl_entry_new();
@@ -398,11 +399,12 @@
m-imagetree = ewl_tree_new(1);
ewl_container_child_append(EWL_CONTAINER(m-images), 
m-imagetree);
ewl_object_maximum_size_set(EWL_OBJECT(m-imagetree), 200, 160);
+   ewl_object_fill_policy_set(EWL_OBJECT(m-imagetree), 
EWL_FLAG_FILL_VFILL);
ewl_widget_show(m-imagetree);
 
m-notebook = ewl_notebook_new();
ewl_notebook_tabbar_position_set(EWL_NOTEBOOK(m-notebook), 
EWL_POSITION_TOP);
-   ewl_object_preferred_inner_size_set(EWL_OBJECT(m-notebook), 
440, 35);
+   ewl_object_preferred_inner_size_set(EWL_OBJECT(m-notebook), 
440, 45);
ewl_container_child_append(EWL_CONTAINER(m-hbox), m-notebook);
ewl_object_alignment_set(EWL_OBJECT(m-notebook), 
EWL_FLAG_ALIGN_CENTER);
ewl_object_fill_policy_set(EWL_OBJECT(m-notebook), 
EWL_FLAG_FILL_ALL);
@@ -463,7 +465,6 @@
 
m-iscroll = ewl_scrollpane_new();
 ewl_container_child_append(EWL_CONTAINER(m-content), 
m-iscroll);
-ewl_object_fill_policy_set(EWL_OBJECT(m-iscroll), 
EWL_FLAG_FILL_ALL);
 ewl_widget_show(m-iscroll);

ewl_container_child_append(EWL_CONTAINER(m-iscroll), m-ib);   

@@ -474,8 +475,8 @@
ewl_container_child_append(EWL_CONTAINER(m-vbox2), 
m-settings);
ewl_object_alignment_set(EWL_OBJECT(m-settings), 
EWL_FLAG_ALIGN_CENTER);
ewl_box_spacing_set(EWL_BOX(m-settings), 5);
-   ewl_object_minimum_size_set(EWL_OBJECT(m-settings), 400, 200);
-   ewl_object_maximum_size_set(EWL_OBJECT(m-settings), 9, 
200);
+   

E CVS: proto moom

2006-05-13 Thread Enlightenment CVS
Enlightenment CVS committal

Author  : moom
Project : e17
Module  : proto

Dir : e17/proto/etk/src/lib


Modified Files:
etk_scrolled_view.c 


Log Message:
* Show the viewport created by etk_scrolled_view_add_with_viewport()


===
RCS file: /cvs/e/e17/proto/etk/src/lib/etk_scrolled_view.c,v
retrieving revision 1.15
retrieving revision 1.16
diff -u -3 -r1.15 -r1.16
--- etk_scrolled_view.c 7 Apr 2006 15:36:11 -   1.15
+++ etk_scrolled_view.c 13 May 2006 21:46:24 -  1.16
@@ -110,6 +110,9 @@
else
{
   viewport = etk_viewport_new();
+  etk_widget_visibity_locked_set(viewport, ETK_TRUE);
+  etk_widget_show(viewport, ETK_TRUE);
+  
   etk_container_add(ETK_CONTAINER(scrolled_view), viewport);
}
 




---
Using Tomcat but need to do more? Need to support web services, security?
Get stuff done quickly with pre-integrated technology to make your job easier
Download IBM WebSphere Application Server v.1.0.1 based on Apache Geronimo
http://sel.as-us.falkag.net/sel?cmd=lnkkid=120709bid=263057dat=121642
___
enlightenment-cvs mailing list
enlightenment-cvs@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/enlightenment-cvs


E CVS: cpu e-taro

2006-05-13 Thread Enlightenment CVS
Enlightenment CVS committal

Author  : e-taro
Project : e_modules
Module  : cpu

Dir : e_modules/cpu/po


Added Files:
bg.po 


Log Message:
cpu bg.po (Luchezar P. Petkov), and also do not install the .edj source files, 
just dist them





---
Using Tomcat but need to do more? Need to support web services, security?
Get stuff done quickly with pre-integrated technology to make your job easier
Download IBM WebSphere Application Server v.1.0.1 based on Apache Geronimo
http://sel.as-us.falkag.net/sel?cmd=lnkkid=120709bid=263057dat=121642
___
enlightenment-cvs mailing list
enlightenment-cvs@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/enlightenment-cvs


E CVS: apps/e raster

2006-05-13 Thread Enlightenment CVS
Enlightenment CVS committal

Author  : raster
Project : e17
Module  : apps/e

Dir : e17/apps/e/src/bin


Modified Files:
e_config.c e_int_config_background.c e_int_config_desklock.c 
e_remote_main.c 


Log Message:


some illogict patches :)

===
RCS file: /cvs/e/e17/apps/e/src/bin/e_config.c,v
retrieving revision 1.168
retrieving revision 1.169
diff -u -3 -r1.168 -r1.169
--- e_config.c  12 May 2006 15:07:39 -  1.168
+++ e_config.c  13 May 2006 03:04:35 -  1.169
@@ -509,7 +509,7 @@
IFCFG(0x008d);
e_config-show_splash = 1;
e_config-desktop_default_background = NULL;
-   e_config-desktop_default_name = evas_stringshare_add(Desktop %i, %i);
+   e_config-desktop_default_name = evas_stringshare_add(_(Desktop %i, %i));
e_config-menus_scroll_speed = 1000.0;
e_config-menus_fast_mouse_move_threshhold = 300.0;
e_config-menus_click_drag_timeout = DEF_MENUCLICK;
===
RCS file: /cvs/e/e17/apps/e/src/bin/e_int_config_background.c,v
retrieving revision 1.48
retrieving revision 1.49
diff -u -3 -r1.48 -r1.49
--- e_int_config_background.c   2 May 2006 06:23:55 -   1.48
+++ e_int_config_background.c   13 May 2006 03:04:35 -  1.49
@@ -306,7 +306,7 @@
else
  ic = e_thumb_evas_object_get(c, cfd-dia-win-evas, 48, 48, 1);
 
-   e_widget_ilist_append(il, ic, Theme Background, 
_ilist_cb_bg_selected, cfd, );
+   e_widget_ilist_append(il, ic, _(Theme Background), 
_ilist_cb_bg_selected, cfd, );
if (!e_config-desktop_default_background) selnum = i;
i++;
  }
@@ -316,8 +316,6 @@
 e_zone_current_get(cfd-dia-win-container)-w);
e_widget_preview_edje_set(im, f, desktop/background);
evas_object_del(bg_obj);
-//   im = e_widget_preview_add_from_object(cfd-dia-win-evas, bg_obj, 320, 
240);
-//   e_widget_preview_object_set(im, e_thumb_evas_object_get(c, 
cfd-dia-win-evas, 320, 240, 1));
 
evas_object_del(o);
ecore_evas_free(eebuf);
@@ -384,10 +382,10 @@
  selnum = i;
  
  evas_object_del(im);
- im = e_widget_preview_add(cfd-dia-win-evas, 320, 240);
+ im = e_widget_preview_add(cfd-dia-win-evas, 320, 
+   (320 * 
e_zone_current_get(cfd-dia-win-container)-h) /
+   
e_zone_current_get(cfd-dia-win-container)-w);
  e_widget_preview_edje_set(im, 
e_config-desktop_default_background, desktop/background);
- // im = e_widget_preview_add_from_object(cfd-dia-win-evas, 
o, 320, 240);
- // e_widget_preview_object_set(im, 
e_thumb_evas_object_get(full_path, cfd-dia-win-evas, 320, 240, 1));
   }
 i++;
  }
@@ -420,12 +418,10 @@

theme = e_theme_edje_file_get(base/theme/backgrounds, 
desktop/background);
e_widget_preview_edje_set(cfd-data, theme, desktop/background);
-// e_widget_preview_object_set(cfd-data, 
e_thumb_evas_object_get(strdup(theme), evas, 320, 240, 1));
  }
else
  {
e_widget_preview_edje_set(cfd-data, cfdata-bg, desktop/background);
-// e_widget_preview_object_set(cfd-data, 
e_thumb_evas_object_get(cfdata-bg, evas, 320, 240, 1));
  }
 
if (cfdata-current_bg)
===
RCS file: /cvs/e/e17/apps/e/src/bin/e_int_config_desklock.c,v
retrieving revision 1.14
retrieving revision 1.15
diff -u -3 -r1.14 -r1.15
--- e_int_config_desklock.c 30 Apr 2006 04:31:42 -  1.14
+++ e_int_config_desklock.c 13 May 2006 03:04:35 -  1.15
@@ -8,7 +8,8 @@
 #define BG_LIST_ICON_SIZE_H 32
 
 #define BG_PREVIEW_W 280
-#define BG_PREVIEW_H 200
+#define BG_PREVIEW_H ((BG_PREVIEW_W * 
e_zone_current_get(cfd-dia-win-container)-h) / \
+e_zone_current_get(cfd-dia-win-container)-w)
 
 #define DEF_DESKLOCK_BACKGROUNDtheme_desklock_background
 #define DEF_THEME_BACKGROUND   theme_background
@@ -53,6 +54,8 @@
 
 struct _E_Config_Dialog_Data
 {
+   E_Config_Dialog *cfd;
+   
char *desklock_passwd;
char *desklock_passwd_cp;
int show_password; // local
@@ -203,6 +206,7 @@
   cfdata = E_NEW(E_Config_Dialog_Data, 1);
   cfdata-desklock_passwd = strdup();
   cfdata-desklock_passwd_cp = strdup();
+  cfdata-cfd = cfd;
 
   _fill_desklock_data(cfdata);
 
@@ -654,6 +658,7 @@
 static void
 _load_bgs(E_Config_Dialog_Data *cfdata)
 {
+  E_Config_Dialog *cfd;
   Evas_Object *o, *ic, *im;
   Ecore_Evas *eebuf;
   Evas *evasbuf;
@@ -664,6 +669,7 @@
   if (!cfdata || !cfdata-gui.bg_list)
 return;
 
+  cfd = cfdata-cfd;
   eebuf = ecore_evas_buffer_new(1, 1);
   evasbuf = ecore_evas_get(eebuf);
 
@@ -680,7 +686,7 @@
   else
ic = e_thumb_evas_object_get(c, cfdata-evas, 

E CVS: proto moom

2006-05-13 Thread Enlightenment CVS
Enlightenment CVS committal

Author  : moom
Project : e17
Module  : proto

Dir : e17/proto/etk/src/lib


Modified Files:
etk_scrolled_view.c 


Log Message:
* Make it compile actually!


===
RCS file: /cvs/e/e17/proto/etk/src/lib/etk_scrolled_view.c,v
retrieving revision 1.16
retrieving revision 1.17
diff -u -3 -r1.16 -r1.17
--- etk_scrolled_view.c 13 May 2006 21:46:24 -  1.16
+++ etk_scrolled_view.c 13 May 2006 22:07:27 -  1.17
@@ -110,8 +110,8 @@
else
{
   viewport = etk_viewport_new();
-  etk_widget_visibity_locked_set(viewport, ETK_TRUE);
-  etk_widget_show(viewport, ETK_TRUE);
+  etk_widget_visibility_locked_set(viewport, ETK_TRUE);
+  etk_widget_show(viewport);
   
   etk_container_add(ETK_CONTAINER(scrolled_view), viewport);
}




---
Using Tomcat but need to do more? Need to support web services, security?
Get stuff done quickly with pre-integrated technology to make your job easier
Download IBM WebSphere Application Server v.1.0.1 based on Apache Geronimo
http://sel.as-us.falkag.net/sel?cmd=lnkkid=120709bid=263057dat=121642
___
enlightenment-cvs mailing list
enlightenment-cvs@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/enlightenment-cvs


E CVS: proto titan

2006-05-13 Thread Enlightenment CVS
Enlightenment CVS committal

Author  : titan
Project : e17
Module  : proto

Dir : e17/proto/ephoto/src


Modified Files:
ephoto_presentation.c 


Log Message:

You can now resize slideshow and presentation windows.

===
RCS file: /cvs/e/e17/proto/ephoto/src/ephoto_presentation.c,v
retrieving revision 1.15
retrieving revision 1.16
diff -u -3 -r1.15 -r1.16
--- ephoto_presentation.c   13 May 2006 21:06:16 -  1.15
+++ ephoto_presentation.c   13 May 2006 22:42:09 -  1.16
@@ -397,7 +397,7 @@
ewl_window_class_set(EWL_WINDOW(s-wins), Presentation);
if ( mainwin == 1 ) {
if ( ewl_checkbutton_is_checked(EWL_CHECKBUTTON(m-fullrad)) == 
0 ) {
-   ewl_object_maximum_size_set(EWL_OBJECT(s-wins), ws, h);
+   ewl_object_size_request(EWL_OBJECT(s-wins), ws, h);
}
if ( ewl_checkbutton_is_checked(EWL_CHECKBUTTON(m-fullrad)) == 
1 ) {
ewl_callback_append(s-wins, EWL_CALLBACK_REALIZE, 
realize_cb, NULL);
@@ -408,7 +408,7 @@
ewl_callback_append(s-wins, EWL_CALLBACK_REALIZE, 
realize_cb, NULL);
}
if ( argfullscreen == 0 ) {
-   ewl_object_maximum_size_set(EWL_OBJECT(s-wins), ws, h);
+   ewl_object_size_request(EWL_OBJECT(s-wins), ws, h);
}
}
ewl_callback_append(s-wins, EWL_CALLBACK_DELETE_WINDOW, destroyp_cb, 
NULL);




---
Using Tomcat but need to do more? Need to support web services, security?
Get stuff done quickly with pre-integrated technology to make your job easier
Download IBM WebSphere Application Server v.1.0.1 based on Apache Geronimo
http://sel.as-us.falkag.net/sel?cmd=lnkkid=120709bid=263057dat=121642
___
enlightenment-cvs mailing list
enlightenment-cvs@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/enlightenment-cvs


E CVS: proto moom

2006-05-13 Thread Enlightenment CVS
Enlightenment CVS committal

Author  : moom
Project : e17
Module  : proto

Dir : e17/proto/etk/src/lib


Modified Files:
etk_alignment.c etk_box.c etk_box.h etk_button.h etk_canvas.c 
etk_combobox.c etk_combobox.h 


Log Message:
* [Etk_Box]Remove etk_box_child_reorder() because the position number 
doesn't really make sense in a box. If you want to reorder the children, 
you can just repack them
* [Etk_Box]Implementation of etk_box_child_packing_set/get() to set/get 
the packing settings of a child of a box
* [Etk_Box]Fix the focus order
* [Etk_Combobox] Add etk_combobox_item_prepend/append_relative to the 
API, to add an item before/aftern an existing item
* [Etk_Combobox] The item height can now be defined by the theme. And 
also by the user with etk_combobox_item_height_set()
* Formatting and English fixes


===
RCS file: /cvs/e/e17/proto/etk/src/lib/etk_alignment.c,v
retrieving revision 1.5
retrieving revision 1.6
diff -u -3 -r1.5 -r1.6
--- etk_alignment.c 12 May 2006 19:13:39 -  1.5
+++ etk_alignment.c 13 May 2006 23:44:40 -  1.6
@@ -214,7 +214,7 @@
Etk_Alignment *alignment;
Etk_Widget *child;
Etk_Container *container;
-   Etk_Size child_requisition;
+   Etk_Size child_size;
 
if (!(alignment = ETK_ALIGNMENT(widget)))
   return;
@@ -223,24 +223,24 @@
 
if ((child = etk_bin_child_get(ETK_BIN(alignment
{
-  etk_widget_size_request(child, child_requisition);
+  etk_widget_size_request(child, child_size);
 
   geometry.x += etk_container_border_width_get(container);
   geometry.y += etk_container_border_width_get(container);
   geometry.w -= 2 * etk_container_border_width_get(container);
   geometry.h -= 2 * etk_container_border_width_get(container);
 
-  if (geometry.w  child_requisition.w)
+  if (geometry.w  child_size.w)
   {
- child_requisition.w += alignment-xscale * (geometry.w - 
child_requisition.w);
- geometry.x += alignment-xalign * (geometry.w - child_requisition.w);
- geometry.w = child_requisition.w;
+ child_size.w += alignment-xscale * (geometry.w - child_size.w);
+ geometry.x += alignment-xalign * (geometry.w - child_size.w);
+ geometry.w = child_size.w;
   }
-  if (geometry.h  child_requisition.h)
+  if (geometry.h  child_size.h)
   {
- child_requisition.h += alignment-yscale * (geometry.h - 
child_requisition.h);
- geometry.y += alignment-yalign * (geometry.h - child_requisition.h);
- geometry.h = child_requisition.h;
+ child_size.h += alignment-yscale * (geometry.h - child_size.h);
+ geometry.y += alignment-yalign * (geometry.h - child_size.h);
+ geometry.h = child_size.h;
   }
 
   etk_widget_size_allocate(child, geometry);
===
RCS file: /cvs/e/e17/proto/etk/src/lib/etk_box.c,v
retrieving revision 1.11
retrieving revision 1.12
diff -u -3 -r1.5 -r1.6
--- combobox.edc11 Apr 2006 15:03:12 -  1.5
+++ combobox.edc13 May 2006 23:44:40 -  1.6
@@ -1,4 +1,10 @@
 group {
+   name: combobox;
+   data {
+  item: item_height 24;
+   }
+}
+group {
name: combobox/button;
min: 0 32;
parts {




---
Using Tomcat but need to do more? Need to support web services, security?
Get stuff done quickly with pre-integrated technology to make your job easier
Download IBM WebSphere Application Server v.1.0.1 based on Apache Geronimo
http://sel.as-us.falkag.net/sel?cmd=lnkkid=120709bid=263057dat=121642
___
enlightenment-cvs mailing list
enlightenment-cvs@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/enlightenment-cvs


E CVS: apps/e raster

2006-05-13 Thread Enlightenment CVS
Enlightenment CVS committal

Author  : raster
Project : e17
Module  : apps/e

Dir : e17/apps/e/src/bin


Modified Files:
e_apps.c e_apps.h e_border.c e_eap_editor.c 
e_int_border_menu.c 


Log Message:


eap icons update realtime in borders based off on-disk changes etc. etc.
(editing icons seems to work like a charm for me so far).

===
RCS file: /cvs/e/e17/apps/e/src/bin/e_apps.c,v
retrieving revision 1.134
retrieving revision 1.135
diff -u -3 -r1.134 -r1.135
--- e_apps.c13 May 2006 16:05:15 -  1.134
+++ e_apps.c14 May 2006 01:13:42 -  1.135
@@ -444,6 +444,7 @@
 {
Ecore_Exe *exe;
E_App_Instance *inst;
+   Evas_List *l;

E_OBJECT_CHECK_RETURN(a, 0);
E_OBJECT_TYPE_CHECK_RETURN(a, E_APP_TYPE, 0);
@@ -476,6 +477,13 @@
 //   e_object_ref(E_OBJECT(a));
_e_apps_start_pending = evas_list_append(_e_apps_start_pending, a);
if (a-startup_notify) a-starting = 1;
+   for (l = a-references; l; l = l-next)
+ {
+   E_App *a2;
+   
+   a2 = l-data;
+   _e_app_change(a2, E_APP_EXEC);
+ }
_e_app_change(a, E_APP_EXEC);
return 1;
 }
@@ -759,13 +767,13 @@
 EAPI void
 e_app_remove(E_App *a)
 {
+   Evas_List *l;
char buf[PATH_MAX];
 
if (!a) return;
if (!a-parent) return;
 
a-parent-subapps = evas_list_remove(a-parent-subapps, a);
-
/* Check if this app is in a repository or in the parents dir */
snprintf(buf, sizeof(buf), %s/%s, a-parent-path, 
ecore_file_get_file(a-path));
if (ecore_file_exists(buf))
@@ -777,8 +785,16 @@
a-path = evas_stringshare_add(buf);
  }
_e_app_save_order(a-parent);
+   for (l = a-references; l; l = l-next)
+ {
+   E_App *a2;
+   
+   a2 = l-data;
+   e_app_remove(a2);
+ }
_e_app_change(a, E_APP_DEL);
a-parent = NULL;
+   e_object_unref(E_OBJECT(a));
 }
 
 EAPI void
@@ -1295,7 +1311,17 @@
eet_close(ef);
if (a-parent)
  {
+   Evas_List *l;
+   
_e_app_change(a-parent, E_APP_CHANGE);
+   _e_app_change(a, E_APP_CHANGE);
+   for (l = a-references; l; l = l-next)
+ {
+E_App *a2;
+
+a2 = l-data;
+if (_e_app_copy(a2, a)) _e_app_change(a2, E_APP_CHANGE);
+ }
_e_app_subdir_rescan(a-parent);
  }
 }
@@ -1565,8 +1591,13 @@
  }
/* If this is an original, it wont be deleted until all references
 * are gone */
-   if (a-references)
+   while (a-references)
  {
+E_App *a2;
+
+a2 = a-references-data;
+a2-orig = NULL;
+a-references = evas_list_remove_list(a-references, 
a-references);
 printf(BUG: An original eapp shouldn't have any references when 
freed! %d\n, evas_list_count(a-references));
  }
 
@@ -1603,16 +1634,19 @@
 {
Evas_List *l;
 
+   if (ch == E_APP_DEL)
+ printf(APP_DEL %s\n, a-path);
+   if (ch == E_APP_CHANGE)
+ printf(APP_CHANGE %s\n, a-path);
+   if (ch == E_APP_ADD)
+ printf(APP_ADD %s\n, a-path);
_e_apps_callbacks_walking = 1;
for (l = _e_apps_change_callbacks; l; l = l-next)
  {
E_App_Callback *cb;

cb = l-data;
-   if (!cb-delete_me)
- {
-cb-func(cb-data, a, ch);
- }
+   if (!cb-delete_me) cb-func(cb-data, a, ch);
  }
_e_apps_callbacks_walking = 0;
if (_e_apps_callbacks_delete_me)
@@ -1641,6 +1675,7 @@
 {
E_App *app;
char  *file;
+   Evas_List *l;

app = data;
if ((!app) || (app-deleted))
@@ -1675,6 +1710,13 @@
 e_app_fields_empty(app);
 e_app_fields_fill(app, path);
 _e_app_change(app, E_APP_CHANGE);
+for (l = app-references; l; l = l-next)
+  {
+ E_App *a2;
+ 
+ a2 = l-data;
+ if (_e_app_copy(a2, app)) _e_app_change(a2, E_APP_CHANGE);
+  }
  }
else if (event == ECORE_FILE_EVENT_DELETED_FILE)
  {
@@ -1720,7 +1762,6 @@
  else
{
   _e_app_change(a, E_APP_CHANGE);
-
   for (l = a-references; l; l = l-next)
 {
E_App *a2;
@@ -1996,6 +2037,7 @@
Ecore_Exe_Event_Del *ev;
E_App_Instance *ai;
E_App *a;
+   Evas_List *l;
 
ev = event;
if (!ev-exe) return 1;
@@ -2049,6 +2091,13 @@
free(ai);
a-instances = evas_list_remove(a-instances, ai);
_e_apps_start_pending = evas_list_remove(_e_apps_start_pending, a);
+   for (l = a-references; l; l = l-next)
+ {
+   E_App *a2;
+   
+   a2 = l-data;
+   _e_app_change(a2, E_APP_EXIT);
+ }
_e_app_change(a, E_APP_EXIT);
return 1;
 }
@@ -2085,6 +2134,13 @@
while (removes)
  {
a = removes-data;
+   for (l = a-references; 

E CVS: apps/e raster

2006-05-13 Thread Enlightenment CVS
Enlightenment CVS committal

Author  : raster
Project : e17
Module  : apps/e

Dir : e17/apps/e/src/modules/ibar


Modified Files:
e_mod_main.c 


Log Message:


ibar picks up name changes now

===
RCS file: /cvs/e/e17/apps/e/src/modules/ibar/e_mod_main.c,v
retrieving revision 1.118
retrieving revision 1.119
diff -u -3 -r1.118 -r1.119
--- e_mod_main.c14 May 2006 01:13:42 -  1.118
+++ e_mod_main.c14 May 2006 01:30:10 -  1.119
@@ -538,7 +538,6 @@
ic-o_holder = edje_object_add(evas_object_evas_get(b-o_box));
e_theme_edje_object_set(ic-o_holder, base/theme/modules/ibar,
   modules/ibar/icon);
-   edje_object_part_text_set(ic-o_holder, label, a-name);
evas_object_event_callback_add(ic-o_holder, EVAS_CALLBACK_MOUSE_IN,  
_ibar_cb_icon_mouse_in,  ic);
evas_object_event_callback_add(ic-o_holder, EVAS_CALLBACK_MOUSE_OUT, 
_ibar_cb_icon_mouse_out, ic);
evas_object_event_callback_add(ic-o_holder, EVAS_CALLBACK_MOUSE_DOWN, 
_ibar_cb_icon_mouse_down, ic);
@@ -551,7 +550,6 @@
ic-o_holder2 = edje_object_add(evas_object_evas_get(b-o_box));
e_theme_edje_object_set(ic-o_holder2, base/theme/modules/ibar,
   modules/ibar/icon_overlay);
-   edje_object_part_text_set(ic-o_holder2, label, a-name);
evas_object_layer_set(ic-o_holder2, );
evas_object_pass_events_set(ic-o_holder2, 1);
evas_object_show(ic-o_holder2);
@@ -593,6 +591,9 @@
edje_object_part_swallow(ic-o_holder2, item, ic-o_icon2);
evas_object_pass_events_set(ic-o_icon2, 1);
evas_object_show(ic-o_icon2);
+   
+   edje_object_part_text_set(ic-o_holder, label, ic-app-name);
+   edje_object_part_text_set(ic-o_holder2, label, ic-app-name);
 }
 
 static void




---
Using Tomcat but need to do more? Need to support web services, security?
Get stuff done quickly with pre-integrated technology to make your job easier
Download IBM WebSphere Application Server v.1.0.1 based on Apache Geronimo
http://sel.as-us.falkag.net/sel?cmd=lnkkid=120709bid=263057dat=121642
___
enlightenment-cvs mailing list
enlightenment-cvs@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/enlightenment-cvs


E CVS: moon e-taro

2006-05-13 Thread Enlightenment CVS
Enlightenment CVS committal

Author  : e-taro
Project : e_modules
Module  : moon

Dir : e_modules/moon




Log Message:
Moon module - a gadget that displays moon phase information for e17
* gadconized
* the default images are the fugly ones from the e16 E-MoonClock
* configuration works, but isn't persisted properly yet
* i18n is ready to go (Haga-san - feel free to update the ja.po :))

Status:

Vendor Tag: e-taro
Release Tags:   start

N e_modules/moon/ABOUT-NLS
N e_modules/moon/AUTHORS
N e_modules/moon/COPYING
N e_modules/moon/COPYING-PLAIN
N e_modules/moon/ChangeLog
N e_modules/moon/INSTALL
N e_modules/moon/Makefile.am
N e_modules/moon/NEWS
N e_modules/moon/README
N e_modules/moon/TODO
N e_modules/moon/autogen.sh
N e_modules/moon/configure.ac
N e_modules/moon/data/Makefile.am
N e_modules/moon/data/themes/Makefile.am
N e_modules/moon/data/themes/icon.edc
N e_modules/moon/data/themes/moon.edc
N e_modules/moon/data/themes/images/E-MoonClock-00.png
N e_modules/moon/data/themes/images/E-MoonClock-01.png
N e_modules/moon/data/themes/images/E-MoonClock-02.png
N e_modules/moon/data/themes/images/E-MoonClock-03.png
N e_modules/moon/data/themes/images/E-MoonClock-04.png
N e_modules/moon/data/themes/images/E-MoonClock-05.png
N e_modules/moon/data/themes/images/E-MoonClock-06.png
N e_modules/moon/data/themes/images/E-MoonClock-07.png
N e_modules/moon/data/themes/images/E-MoonClock-08.png
N e_modules/moon/data/themes/images/E-MoonClock-09.png
N e_modules/moon/data/themes/images/E-MoonClock-10.png
N e_modules/moon/data/themes/images/E-MoonClock-11.png
N e_modules/moon/data/themes/images/E-MoonClock-12.png
N e_modules/moon/data/themes/images/E-MoonClock-13.png
N e_modules/moon/data/themes/images/E-MoonClock-14.png
N e_modules/moon/data/themes/images/E-MoonClock-15.png
N e_modules/moon/data/themes/images/E-MoonClock-16.png
N e_modules/moon/data/themes/images/E-MoonClock-17.png
N e_modules/moon/data/themes/images/E-MoonClock-18.png
N e_modules/moon/data/themes/images/E-MoonClock-19.png
N e_modules/moon/data/themes/images/E-MoonClock-20.png
N e_modules/moon/data/themes/images/E-MoonClock-21.png
N e_modules/moon/data/themes/images/E-MoonClock-22.png
N e_modules/moon/data/themes/images/E-MoonClock-23.png
N e_modules/moon/data/themes/images/E-MoonClock-24.png
N e_modules/moon/data/themes/images/E-MoonClock-25.png
N e_modules/moon/data/themes/images/E-MoonClock-26.png
N e_modules/moon/data/themes/images/E-MoonClock-27.png
N e_modules/moon/data/themes/images/E-MoonClock-28.png
N e_modules/moon/data/themes/images/E-MoonClock-29.png
N e_modules/moon/data/themes/images/E-MoonClock-30.png
N e_modules/moon/data/themes/images/E-MoonClock-31.png
N e_modules/moon/data/themes/images/E-MoonClock-32.png
N e_modules/moon/data/themes/images/E-MoonClock-33.png
N e_modules/moon/data/themes/images/E-MoonClock-34.png
N e_modules/moon/data/themes/images/E-MoonClock-35.png
N e_modules/moon/data/themes/images/E-MoonClock-36.png
N e_modules/moon/data/themes/images/E-MoonClock-37.png
N e_modules/moon/data/themes/images/E-MoonClock-38.png
N e_modules/moon/data/themes/images/E-MoonClock-39.png
N e_modules/moon/data/themes/images/E-MoonClock-40.png
N e_modules/moon/data/themes/images/E-MoonClock-41.png
N e_modules/moon/data/themes/images/E-MoonClock-42.png
N e_modules/moon/data/themes/images/E-MoonClock-43.png
N e_modules/moon/data/themes/images/E-MoonClock-44.png
N e_modules/moon/data/themes/images/E-MoonClock-45.png
N e_modules/moon/data/themes/images/E-MoonClock-46.png
N e_modules/moon/data/themes/images/E-MoonClock-47.png
N e_modules/moon/data/themes/images/E-MoonClock-48.png
N e_modules/moon/data/themes/images/E-MoonClock-49.png
N e_modules/moon/data/themes/images/E-MoonClock-50.png
N e_modules/moon/data/themes/images/E-MoonClock-51.png
N e_modules/moon/data/themes/images/E-MoonClock-52.png
N e_modules/moon/data/themes/images/E-MoonClock-53.png
N e_modules/moon/data/themes/images/E-MoonClock-54.png
N e_modules/moon/data/themes/images/E-MoonClock-55.png
N e_modules/moon/data/themes/images/E-MoonClock-56.png
N e_modules/moon/data/themes/images/E-MoonClock-57.png
N e_modules/moon/data/themes/images/E-MoonClock-58.png
N e_modules/moon/data/themes/images/E-MoonClock-59.png
N e_modules/moon/data/themes/images/Makefile.am
N e_modules/moon/data/themes/images/e17_about_sky3.png
N e_modules/moon/data/themes/images/e17_ibar_bg_h.png
N e_modules/moon/data/themes/images/e17_ibar_over_h.png
N e_modules/moon/data/themes/images/moon.png
N e_modules/moon/m4/ac_path_generic.m4
N e_modules/moon/po/Makefile.am
N e_modules/moon/po/ja.po
N e_modules/moon/po/it.po
N e_modules/moon/po/sv.po
N e_modules/moon/src/CalcEphem.c
N e_modules/moon/src/CalcEphem.h
N e_modules/moon/src/Makefile.am
N e_modules/moon/src/Moon.c
N e_modules/moon/src/e_mod_main.c
N e_modules/moon/src/e_mod_main.h
N e_modules/moon/src/e_mod_config.c

No conflicts created by this import





---
Using Tomcat but need to do 

E CVS: e_modules e-taro

2006-05-13 Thread Enlightenment CVS
Enlightenment CVS committal

Author  : e-taro
Module  : e_modules

Dir : e_modules


Modified Files:
README 


Log Message:
update e_modules README for moon

===
RCS file: /cvs/e/e_modules/README,v
retrieving revision 1.3
retrieving revision 1.4
diff -u -3 -r1.3 -r1.4
--- README  10 May 2006 22:52:56 -  1.3
+++ README  14 May 2006 02:31:54 -  1.4
@@ -16,6 +16,8 @@
 
 mem - A module to monitor memory and swap usage.
 
+moon - A module to display moon phase information
+
 net - A module to monitor traffic on a network device.
 
 rain - A module to display rain on the desktop.




---
Using Tomcat but need to do more? Need to support web services, security?
Get stuff done quickly with pre-integrated technology to make your job easier
Download IBM WebSphere Application Server v.1.0.1 based on Apache Geronimo
http://sel.as-us.falkag.net/sel?cmd=lnkkid=120709bid=263057dat=121642
___
enlightenment-cvs mailing list
enlightenment-cvs@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/enlightenment-cvs


E CVS: e-taro e-taro

2006-05-13 Thread Enlightenment CVS
Enlightenment CVS committal

Author  : e-taro
Project : devs
Module  : e-taro

Dir : devs/e-taro


Modified Files:
info.txt 


Log Message:
update my info...

===
RCS file: /cvs/e/devs/e-taro/info.txt,v
retrieving revision 1.1.1.1
retrieving revision 1.2
diff -u -3 -r1.1.1.1 -r1.2
--- info.txt25 Mar 2006 06:37:29 -  1.1.1.1
+++ info.txt14 May 2006 02:55:40 -  1.2
@@ -4,6 +4,5 @@
 Location: Tokyo, Japan
 E-Mail:   [EMAIL PROTECTED]
 WWW:  http://www.geocities.jp/david_at_tokyo/e17/moon/
-Managing: occassional bug fixes, (and soon the moon module... holding off
-  until the shelf/gadcon stuff is ready). If translators don't sign
- up I'll continue with miscellaneous .po file commitery also.
+Managing: moon module, occasional bug fixes elsewhere
+




---
Using Tomcat but need to do more? Need to support web services, security?
Get stuff done quickly with pre-integrated technology to make your job easier
Download IBM WebSphere Application Server v.1.0.1 based on Apache Geronimo
http://sel.as-us.falkag.net/sel?cmd=lnkkid=120709bid=263057dat=121642
___
enlightenment-cvs mailing list
enlightenment-cvs@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/enlightenment-cvs


E CVS: apps/e raster

2006-05-13 Thread Enlightenment CVS
Enlightenment CVS committal

Author  : raster
Project : e17
Module  : apps/e

Dir : e17/apps/e/src/bin


Modified Files:
e_apps.c e_int_border_menu.c 


Log Message:


always write icon file with edje_cc first.

===
RCS file: /cvs/e/e17/apps/e/src/bin/e_apps.c,v
retrieving revision 1.135
retrieving revision 1.136
diff -u -3 -r1.135 -r1.136
--- e_apps.c14 May 2006 01:13:42 -  1.135
+++ e_apps.c14 May 2006 03:49:46 -  1.136
@@ -1210,13 +1210,13 @@
unsigned char tmp[1];
int img;
 
-   if ((!a-path) || (!ecore_file_exists(a-path)))
- {
+//   if ((!a-path) || (!ecore_file_exists(a-path)))
+// {
_e_app_new_save(a);
-   img = 0;
- }
-   else
- img = 1;
+// img = 0;
+// }
+//   else
+// img = 1;
 
/* get our current language */
lang = e_intl_language_alias_get();
@@ -1276,6 +1276,7 @@
  tmp[0] = 0;   
eet_write(ef, app/info/wait_exit, tmp, 1, 0);
 
+   /*
if ((a-image)  (img))
  {
int alpha;
@@ -1298,7 +1299,6 @@
  a-height = EAP_MIN_HEIGHT;   
if ((iw  0)  (ih  0))
  {
-/* we need to change the sizes */
 ecore_evas_resize(buf, a-width, a-height);
 evas_object_image_fill_set(im, 0, 0, a-width, a-height);
 evas_object_resize(im, a-height, a-width);
@@ -1308,6 +1308,7 @@
 eet_data_image_write(ef, images/0, (void *)data, a-width, 
a-height, alpha, 1, 0, 0);
  }
  }
+*/
eet_close(ef);
if (a-parent)
  {
===
RCS file: /cvs/e/e17/apps/e/src/bin/e_int_border_menu.c,v
retrieving revision 1.17
retrieving revision 1.18
diff -u -3 -r1.17 -r1.18
--- e_int_border_menu.c 14 May 2006 02:08:36 -  1.17
+++ e_int_border_menu.c 14 May 2006 03:49:46 -  1.18
@@ -526,6 +526,8 @@
 {
E_App *a;
E_Border *bd;
+   char *bname = NULL, *bclass = NULL;
+   

bd = data;
a = bd-app;
@@ -534,13 +536,18 @@
a = e_app_empty_new(NULL);
if (a)
  {
-if (bd-client.icccm.name) a-win_name = 
evas_stringshare_add(bd-client.icccm.name);
-if (bd-client.icccm.class) a-win_class = 
evas_stringshare_add(bd-client.icccm.class);
+bname = bd-client.icccm.name;
+if ((bname)  (strlen(bname)  1)) bname = NULL;
+bclass = bd-client.icccm.class;
+if ((bclass)  (strlen(bclass)  1)) bclass = NULL;
+
+if (bname) a-win_name = evas_stringshare_add(bname);
+if (bclass) a-win_class = evas_stringshare_add(bclass);
 if (bd-client.icccm.window_role)
   a-win_role = evas_stringshare_add(bd-client.icccm.window_role);
-if (bd-client.icccm.class) a-icon_class = 
evas_stringshare_add(bd-client.icccm.class);
-if (bd-client.icccm.class) a-name = 
evas_stringshare_add(bd-client.icccm.class);
-if (bd-client.icccm.name) a-exe = 
evas_stringshare_add(bd-client.icccm.name);
+if (bclass) a-icon_class = evas_stringshare_add(bclass);
+if (bclass) a-name = evas_stringshare_add(bclass);
+if (bname) a-exe = evas_stringshare_add(bname);
 if (bd-client.netwm.startup_id  0)
   a-startup_notify = 1;
 bd-app = a;
@@ -552,6 +559,19 @@
  e_eap_edit_show(m-zone-container, a-orig);
else
  e_eap_edit_show(m-zone-container, a);
+   if ((!bname)  (!bclass))
+ {
+   e_util_dialog_show(_(Incomplete Window Properties),
+  _(The window you are creating an icon forbr
+does not contain window name and classbr
+properties, so the needed properties forbr
+the icon so that it will be used for thisbr
+window cannot be guessed. You will need tobr
+use the window title instead. This will onlybr
+work if the window title is the same atbr
+the time the window starts up, and does notbr
+change.));
+ }
 }
 
 static void




---
Using Tomcat but need to do more? Need to support web services, security?
Get stuff done quickly with pre-integrated technology to make your job easier
Download IBM WebSphere Application Server v.1.0.1 based on Apache Geronimo
http://sel.as-us.falkag.net/sel?cmd=lnkkid=120709bid=263057dat=121642
___
enlightenment-cvs mailing list
enlightenment-cvs@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/enlightenment-cvs
diff -u -3 -r1.11 -r1.12
--- etk_box.c   13 May 2006 12:04:00 -  1.11
+++ etk_box.c   13 May 2006 23:44:40 -  1.12
@@ -158,42 +158,85 @@
 }
 
 /**
  * @brief Moves the child to a new position in the box
  * @param box a box
- * @param child the child to move
- * @param position the new position of the child
- */ 
-void etk_box_child_reorder(Etk_Box *box, Etk_Widget *child, int position)
+ * @param child a child of the box. If @a child is not packed in the box, this 
function has no effect
+ * @param padding the padding to set to the child. See etk_box_pack_start() 
for more information
+ * @param expand the expand setting to set to the child. See 
etk_box_pack_start() for more information
+ * @param fill the fill setting to set to the child. See etk_box_pack_start() 
for more information
+ * @param pack_end whether or not the child is packed at the end of the box.
+ * See etk_box_pack_start() for more information
+ * @see etk_box_pack_start()
+ */
+void etk_box_child_packing_set(Etk_Box *box, Etk_Widget *child, int padding, 
Etk_Bool expand, Etk_Bool fill, Etk_Bool pack_end)
 {
Evas_List *l;
Etk_Box_Cell *cell;
-   int i;
-
-   if (!box || !child || (child-parent != ETK_WIDGET(box)))
+   
+   if (!box || !child)
   return;
+   
+   for (l = box-cells; l; l = l-next)
+   {
+  cell = l-data;
+  
+  if (cell-child == child)
+  {
+ cell-padding = padding;
+ cell-expand = expand;
+ cell-fill = fill;
+ cell-pack_end = pack_end;
+ etk_widget_size_recalc_queue(ETK_WIDGET(box));
+ return;
+  }
+   }
+}
 
-   position = ETK_CLAMP(0, evas_list_count(box-cells) - 1, position);
-
-   for (l = box-cells, i = 0; l; l = l-next, i++)
+/**
+ * @brief Gets the packing settings of a child of the box
+ * @param box a box
+ * @param child a child of the box. It has to be packed 
@@ -158,42 +158,85 @@
 
 /**
- * @brief Moves the child to a new position in the box
+ * @brief Sets the packing settings of a child of the box
  * @param box a box

E CVS: proto moom

2006-05-13 Thread Enlightenment CVS
Enlightenment CVS committal

Author  : moom
Project : e17
Module  : proto

Dir : e17/proto/etk/data/themes/default/widgets


Modified Files:
combobox.edc 


Log Message:
* [Etk_Box]Remove etk_box_child_reorder() because the position number 
doesn't really make sense in a box. If you want to reorder the children, 
you can just repack them
* [Etk_Box]Implementation of etk_box_child_packing_set/get() to set/get 
the packing settings of a child of a box
* [Etk_Box]Fix the focus order
* [Etk_Combobox] Add etk_combobox_item_prepend/append_relative to the 
API, to add an item before/aftern an existing item
* [Etk_Combobox] The item height can now be defined by the theme. And 
also by the user with etk_combobox_item_height_set()
* Formatting and English fixes


===
RCS file: /cvs/e/e17/proto/etk/data/themes/default/widgets/combobox.edc,v
retrieving revision 1.5
retrieving revision 1.6